require 'rails_helper'

RSpec.describe V1::CollectionsController, type: :controller do
  fixtures :all

  it { should use_before_action(:authenticate_user!) }
  it { should use_before_action(:set_collection) }
  it { should route(:get, '/v1/collections').to(action: :index) }

  describe 'sociable actions' do
    it { should use_before_action(:authorize_sociable!) }
    it { should use_before_action(:view_object!) }
    it { should route(:post, '/v1/collections/1/like').to(action: :like, id: 1) }
    it { should route(:delete, '/v1/collections/1/like').to(action: :unlike, id: 1) }

    describe 'POST #like' do
      before do
        auth_app applications(:test_app), @request
        post :like, id: collections(:ufpr).id
      end

      context 'when user is authenticated' do
        it do
          #user = applications(:test_app).user
          expect(response).to have_http_status(:created)
        end
      end

      context 'when user is not authenticated' do
        it { expect(response).to have_http_status(:unauthorized) }
      end
    end
  end

  describe 'GET #index' do
      before do
        auth_app applications(:test_app), @request
        get :index
      end

      it { expect(response.content_type).to eq('application/json') }
      it { expect(response).to have_http_status(:ok) }
  end

end